@@ -109,13 +109,13 @@ def check_if_statement(template, vars):
 def render_str(template, vars):
     '''Return a string with vars changed in template'''
 
-    template = check_include_statement(template, vars)
-
     # for statement
     template = check_for_statement(template, vars)
     
     # if statement
     template = check_if_statement(template, vars)
+
+    template = check_include_statement(template, vars)
     
     # vars replacing ${var}
     all_vars = CODE.findall(template)
@@ -132,7 +132,13 @@ class template:
     def __init__(self, file='template.spte'):
         self.file = file
     def __call__(self, f):
-        def templated(*args):
-            vars = f(*args)
-            return render(self.file, vars)
+        def templated(*args, **kwargs):
+            vars = f(*args, **kwargs)
+            tmp_file = self.file
+            try:
+                tmp_file = vars['template']
+            except:
+                pass
+
+            return render(tmp_file, vars)
         return templated
